fh-immuta-utils
============

This repository contains a Python wrapper around [Immuta's](https://www.immuta.com) API.
The supported operations include:

* Dis/enrolling data sources
* Creating/managing tags
* Creating/managing policies

Documentation:

* [Getting started](doc/getting_started.md)
* [Configuration](doc/managing_configs.md)
* [Managing data sources](doc/managing_data_sources.md)
* [Managing policies](doc/managing_policies.md)
* [Contributing](CONTRIBUTING.md)
